FILE_EXPORT_RESULT = 'Results.xlsx'
FILE_EXPORT_CLASS = 'Classes.xlsx'
FILE_EXPORT_STUDENT = 'Students.xlsx'
FILE_EXPORT_USER = 'Users.xlsx'
FILE_EXPORT_TEST = 'Tests.xlsx'

TITLE = 'Kanwar Adnan'

DATABASE = "Database.db"
DATABASEATTENDNACE = "Database2.db"

DEFAULT_ROLE = 'Admin'
DEFAULT_ADMIN = 'admin'
DEFAULT_PASSWORD = '123'
DEFAULT_EMAIL = 'admin'
DEFAULT_CLASS = 'IT-G2'
DEFAULT_LECTURE = 'DLD'

DEFAULT_ROLE_USER = 'Teacher'

LOGGER = 'Admin'

font_lbl=  ['Helvetica',12]

CONNECTION_URL = """mongodb+srv://kanwar:adnan272@cluster0.g2peczr.mongodb.net/?retryWrites=true&w=majority
"""
DATABASE_NAME = "pu"
COLLECTION_NAME = 'results20'

PRODUCTION_CONNECTION_URL = """mongodb+srv://kanwar:adnan272@cluster0.g2peczr.mongodb.net/?retryWrites=true&w=majority
"""
PRODUCTION_DATABASE_NAME = "apps"
PRODUCTION_COLLECTION_NAME = 'myOnlineApps'